from django.db import models
import random


class IDField(models.Field):

    def __init__(self, alphabet=None, readable=False, *args, **kwargs):
        self.max_length = kwargs.get('max_length', 10)
        self.readable = readable
        self.alphabet = alphabet
        if not self.alphabet:
            if self.readable:
                self.alphabet = "ABCDEFGHJKMNPQRSTUVWXYZ23456789"
            else:
                self.alphabet = "abcdefghijklmnopqrstuvwxyz0123456789"
        super(IDField, self).__init__(*args, **kwargs)

    def db_type(self, connection):
        return 'char({})'.format(self.max_length)

    def pre_save(self, model_instance, add):
        value = super(IDField, self).pre_save(model_instance, add)
        if not value:
            value = ''
            for i in range(0, self.max_length): value += random.choice(self.alphabet)
            setattr(model_instance, self.attname, value)
        return value

    def formfield(self, **kwargs):
        return super(IDField, self).formfield(**kwargs)

    def deconstruct(self):
        return super(IDField, self).deconstruct()



from __future__  import absolute_import

try:
    VERSION = __import__('pkg_resources').get_distribution('django-idfield').version
except Exception:
    VERSION = 'unknown'

from .fields import IDField



from setuptools import setup, find_packages
from os import path

here = path.abspath(path.dirname(__file__))
with open(path.join(here, 'README.rst'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='django-idfield',
    version='1.0.0',
    author='Alex Lis',
    author_email='a@lis.space',
    description='Char ID fora Django',
    # keywords='sample setuptools development',
    long_description=long_description,
    license='MIT',
    url='https://github.com/lis-space/django-idfield',
    zip_safe=False,
    install_requires=[
        'django',
    ],
    packages=find_packages(),
    include_package_data=True,
    python_requires='>=3',
    classifiers=[
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        'Development Status :: 4 - Beta',
        "Framework :: Django",
        "Operating System :: OS Independent",
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Intended Audience :: Developers',
    ],
)
